You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by gi...@apache.org on 2018/05/07 21:16:55 UTC

[1/5] mesos git commit: Increased the timeout for waiting for `reaped` to be invoked.

Repository: mesos
Updated Branches:
  refs/heads/master 01b618c41 -> 36522a29a


Increased the timeout for waiting for `reaped` to be invoked.

Previously after the container process is reaped by the Docker
executor, we will wait 3 seconds for `reaped` to be invoked.
However in some cases (e.g., launch a Docker container to use
an external rexray volume), there will be more than 3 seconds
after the container process exits and before the `docker run`
command returns (i.e., `reaped` invoked). So in this patch,
the timeout is increased to 60 seconds.

Review: https://reviews.apache.org/r/66947/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/aaf51e00
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/aaf51e00
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/aaf51e00

Branch: refs/heads/master
Commit: aaf51e007044ad295949ad719776ef49d62dc3bf
Parents: 01b618c
Author: Qian Zhang <zh...@gmail.com>
Authored: Mon May 7 13:48:39 2018 -0700
Committer: Gilbert Song <so...@gmail.com>
Committed: Mon May 7 13:48:39 2018 -0700

----------------------------------------------------------------------
 src/docker/executor.cpp | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/aaf51e00/src/docker/executor.cpp
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index 83c4e87..f8feb9c 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1204,6 +1204,7 @@ All Issues:
   * [MESOS-8576] - Improve discard handling of 'Docker::inspect()'.
   * [MESOS-8605] - Terminal task status update will not send if 'docker inspect' is hung.
   * [MESOS-8651] - Potential memory leaks in the `volume/sandbox_path` isolator.
+  * [MESOS-8876] - Normal exit of Docker container using rexray volume results in TASK_FAILED.
 
 
 Release Notes - Mesos - Version 1.3.2


[2/5] mesos git commit: Added MESOS-8876 to 1.6.0 CHANGELOG.

Posted by gi...@apache.org.
Added MESOS-8876 to 1.6.0 CHANGELOG.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/b5b97038
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/b5b97038
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/b5b97038

Branch: refs/heads/master
Commit: b5b970381bc8e616720bb9ff7917920f0ab0974c
Parents: aaf51e0
Author: Gilbert Song <so...@gmail.com>
Authored: Mon May 7 14:11:30 2018 -0700
Committer: Gilbert Song <so...@gmail.com>
Committed: Mon May 7 14:11:30 2018 -0700

----------------------------------------------------------------------
 CHANGELOG | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/b5b97038/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index 0254044..aee7475 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -231,6 +231,7 @@ All Resolved Issues:
     * [MESOS-8868] - Some 'FsTest' test cases fail on macOS
     * [MESOS-8870] - Master does not correctly reconcile dropped operations after agent failover
     * [MESOS-8874] - ResourceProviderManagerHttpApiTest.ResubscribeResourceProvider is flaky.
+    * [MESOS-8876] - Normal exit of Docker container using rexray volume results in TASK_FAILED.
 
 ** Improvement
     * [MESOS-2922] - Add move constructors / assignment to Future.


[3/5] mesos git commit: Added MESOS-8876 to 1.5.1 CHANGELOG.

Posted by gi...@apache.org.
Added MESOS-8876 to 1.5.1 CHANGELOG.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/bad10a88
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/bad10a88
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/bad10a88

Branch: refs/heads/master
Commit: bad10a88f4a7c291add62dfb91d7c2c077582c44
Parents: b5b9703
Author: Gilbert Song <so...@gmail.com>
Authored: Mon May 7 14:12:45 2018 -0700
Committer: Gilbert Song <so...@gmail.com>
Committed: Mon May 7 14:12:45 2018 -0700

----------------------------------------------------------------------
 CHANGELOG | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/bad10a88/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index aee7475..f589e1e 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -378,6 +378,7 @@ Release Notes - Mesos - Version 1.5.1 (WIP)
   * [MESOS-8651] - Potential memory leaks in the `volume/sandbox_path` isolator.
   * [MESOS-8742] - Agent resource provider config API calls should be idempotent.
   * [MESOS-8787] - RP-related API should be experimental.
+  * [MESOS-8876] - Normal exit of Docker container using rexray volume results in TASK_FAILED.
 
 
 Release Notes - Mesos - Version 1.5.0


[4/5] mesos git commit: Added MESOS-8876 to 1.4.2 CHANGELOG.

Posted by gi...@apache.org.
Added MESOS-8876 to 1.4.2 CHANGELOG.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/8b5b35b9
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/8b5b35b9
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/8b5b35b9

Branch: refs/heads/master
Commit: 8b5b35b9f3a792d18c6ddb5dadb0df0657eb4e25
Parents: bad10a8
Author: Gilbert Song <so...@gmail.com>
Authored: Mon May 7 14:13:42 2018 -0700
Committer: Gilbert Song <so...@gmail.com>
Committed: Mon May 7 14:13:42 2018 -0700

----------------------------------------------------------------------
 CHANGELOG | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/8b5b35b9/CHANGELOG
----------------------------------------------------------------------
diff --git a/CHANGELOG b/CHANGELOG
index f589e1e..83c4e87 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -892,6 +892,7 @@ Release Notes - Mesos - Version 1.4.2 (WIP)
   * [MESOS-8604] - Quota headroom tracking may be incorrect in the presence of hierarchical reservation.
   * [MESOS-8605] - Terminal task status update will not send if 'docker inspect' is hung.
   * [MESOS-8651] - Potential memory leaks in the `volume/sandbox_path` isolator.
+  * [MESOS-8876] - Normal exit of Docker container using rexray volume results in TASK_FAILED.
 
 
 Release Notes - Mesos - Version 1.4.1
diff --git a/src/docker/executor.cpp b/src/docker/executor.cpp
index 16509da..572594a 100644
--- a/src/docker/executor.cpp
+++ b/src/docker/executor.cpp
@@ -348,11 +348,11 @@ public:
               // lambda; ideally when the Docker issue mentioned above does
               // not occur, `reaped` will be invoked (i.e., the `docker run`
               // command returns) to get the actual exit status of the
               // container, so here we wait a few seconds for `reaped` to be
               // invoked. If `reaped` is not invoked within the timeout, that
               // means we hit that Docker issue.
               delay(
-                  Seconds(3),
+                  Seconds(60),
                   self(),
                   &Self::reapedContainer,
                   container.pid.get());
@@ -361,10 +361,10 @@ public:
             }));
         } else {
           // This is the case that the container process has already exited,
           // Similar to the above case, let's wait a few seconds for `reaped`
           // to be invoked.
           delay(
-              Seconds(3),
+              Seconds(60),
               self(),
               &Self::reapedContainer,
               None());


[5/5] mesos git commit: Added MESOS-8876 to 1.3.3 CHANGELOG.

Posted by gi...@apache.org.
Added MESOS-8876 to 1.3.3 CHANGELOG.


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/36522a29
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/36522a29
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/36522a29

Branch: refs/heads/master
Commit: 36522a29adcffebcbaaee66d67ee66b40dcdee8f
Parents: 8b5b35b
Author: Gilbert Song <so...@gmail.com>
Authored: Mon May 7 14:14:00 2018 -0700
Committer: Gilbert Song <so...@gmail.com>
Committed: Mon May 7 14:14:00 2018 -0700

----------------------------------------------------------------------
 CHANGELOG | 1 +
 1 file changed, 1 insertion(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/36522a29/CHANGELOG
----------------------------------------------------------------------
@@ -348,11 +348,11 @@ public:
               // not occur, `reaped` will be invoked (i.e., the `docker run`
               // command returns) to get the actual exit status of the
-              // container, so here we wait a few seconds for `reaped` to be
+              // container, so here we wait 60 seconds for `reaped` to be
               // invoked. If `reaped` is not invoked within the timeout, that
               // means we hit that Docker issue.
@@ -361,10 +361,10 @@ public:
         } else {
           // This is the case that the container process has already exited,
-          // Similar to the above case, let's wait a few seconds for `reaped`
+          // Similar to the above case, let's wait 60 seconds for `reaped`
           // to be invoked.
           delay(